@@ -25,11 +25,9 @@
 #include <QApplication>
 #include <QElapsedTimer>
 
-#include <KDebug>
-
 KItemListKeyboardSearchManager::KItemListKeyboardSearchManager(QObject* parent) :
     QObject(parent),
-    m_timeout(5000)
+    m_timeout(1000)
 {
     m_keyboardInputTime.invalidate();
 }
@@ -76,3 +74,17 @@ qint64 KItemListKeyboardSearchManager::timeout() const
     return m_timeout;
 }
 
+void KItemListKeyboardSearchManager::cancelSearch()
+{
+    m_searchedString.clear();
+}
+
+void KItemListKeyboardSearchManager::slotCurrentChanged(int current, int previous)
+{
+    Q_UNUSED(previous);
+
+    if (current < 0) {
+        // The current item has been removed. We should cancel the search.
+        cancelSearch();
+    }
+}
