@@ -58,6 +58,12 @@ public:
     void setTimeout(qint64 milliseconds);
     qint64 timeout() const;
 
+    void cancelSearch();
+
+public slots:
+
+    void slotCurrentChanged(int current, int previous);
+
 signals:
     /**
      * Is emitted if the current item should be changed corresponding
