@@ -740,12 +740,6 @@ private:
     QByteArray sortRoleForSorting(Sorting sorting) const;
     Sorting sortingForSortRole(const QByteArray& sortRole) const;
 
-    /**
-     * Returns the text for the filesize by converting it to the best fitting
-     * unit.
-     */
-    static QString fileSizeText(KIO::filesize_t fileSize);
-
 private:
     bool m_active;
     bool m_tabsForFiles;
