@@ -1788,7 +1788,7 @@ void IconView::keyPressEvent(QKeyEvent *event)
 
         newItem = currentIndex.row() + hdirection*hMultiplier + vdirection*vMultiplier;
 
-        if ( (newItem < 0) || (newItem >= m_dirModel->rowCount()) ) {
+        if ( (newItem < 0) || (newItem >= m_model->rowCount()) ) {
             newItem = prevItem;
         }
 
@@ -2396,7 +2396,9 @@ void IconView::changeEvent(QEvent *event)
             }
             m_validRows = 0;
             m_delayedLayoutTimer.start(10, this);
-            m_delayedCacheClearTimer.start(5000, this);
+            if (m_delayedCacheClearTimer.isActive()) {
+                m_delayedCacheClearTimer.start(5000, this);
+            }
         }
 
         if (m_validRows == 0) {
